% This is the list of all french macros introduced/modified by the french style
%
% After Bernard Gaulle's decease this work is now maintained as
% the e-French project by a group of enthusiast users 
% under LPPL copyright as declared in http://www.efrench.org/
%
% to be used only for testing/debugging purposes.
%
% All pseudo standard titles cs (like \slidename) are omitted. 
% Just specific french macros are there.
%                                                              rev. 2005/03/24
\dummydef[french,english,frenchtest,frenchdoc,NouveauLangage,%        % 5
beginlanguage,inferieura,superieura,lqq,rqq,originalinput,%           %10
nonfrench,endnonfrench,frenchtypography,noTeXdots,TeXdots,%           %15
ancientguillemets,todayguillemets,guillemetsinallfonts,%18
                                      guillemetsinroman,endguillemets,%20
noenglishquote,englishquote,noenglishdoublequotes,englishdoublequotes,%24
                                                        untypedspaces,%25
typedspaces,idotless,iwithdot,EBCDICbrackets,normalbrackets,%         %30
letpunctutionactivefor,wrongtypedspaces,nofrenchtypography,%33
                               frenchlayout,everyparguillemetsremoved,%35
everyparguillemets,noeveryparguillemets,overfullhboxmark,%38
                                    nooverfullhboxmark,labelsinmargin,%40
nolabelsinmargin,Numeros,nopagenumbers,order,nofrenchlayout,%         %45
frenchtranslation,resume,sommaire,annexe,annexes,%                    %50
glossaire,glossaires,printindex,see,seealso,%                         %55
nofrenchtranslation,frenchmacros,dittomark,frenchname,ordinal,%       %60
keywords,endkeywords,motsclef,endmotsclef,pmfrench,%                  %65
CheckSevenBits,frenchhyphenation,nofrenchhyphenation,hyphex,frhyphex,%%70
letpunctuationactivefor,endfrench,prefacename,vert,tilde,%            %75
automaticlettrine,noautomaticlettrine,frenchguillemets,%78
                                        nofrenchguillemets,wideletter,%80
abbreviations,noabbreviations,nofrenchmacros,frenchstyleid,%84
                                                       originaloutput,%85
abstract,endabstract,email,unnumberedcaptions,nowrongtypedspaces,%    %90
<,>,endorder,Ordinale,Ordinal,%                                       %95
allowuchyph,disallowuchyph,versatim,usualmessages,nohyphenation,%    %100
endversatim,tthyphenation,notthyphenation,!,tabbingaccents,%         %105
notabbingaccents,usersfrenchoptions,PS,yourref,ourref,%              %110
object,AllTeX,ordinale,guillemetsinarrays,noguillemetsinarrays,%     %115
pointvirgule,deuxpoints,pointexclamation,kbtypeout,%119
                                                  pointinterrogation,%120
guillemets,regularmathcomma,frenchmathcomma,frenchwarnings,%124
                                                    nofrenchwarnings,%125
frenchtrivsepwarnings,nofrenchtrivsepwarnings,emailname,fraddto,%129
nombre,%                                                             %130
frtrivseplengths,frlabelitems,checkitemguillemets,indentfirst,%      %135
nonindentfirst,kbIO,ConstantLayout,WindowsUnits,verbatimfile,%       %140
frenchpagestyle,nofrenchpagestyle,beginingfolio,nobeginingfolio,%    %144
                                                            FileName,%145
theFileName,frenchbguillemets,nofrenchbguillemets,%
                             FrenchGuillemetsFrom,CyrillicGuillemets,%150
PolishGuillemets,LasyGuillemets,og,fg,%                      %154
                      %
                      % 154 commandes definies avant \begin{document}%
                      %----------------------------------------------%
%
%%%%%%%%%%%%%
% Macros defined after \begin{document}
%
ier,iere,ieme,iers,ieres,%                                           %005
iemes,numeros,lettrinefont,degre,degres,%                            %010
leftguillemets,rightguillemets,fup,primo,secundo,%                   %015
tertio,quarto,quando,fsc,refmark,%                                   %020
moretolerance,Sauter,lsc,vers,formfoot,%                             %025
formhead,figurette,endfigurette,printglossary,lettrine,%             %030
flettrine,at,chap,lettrinehang,lettrinefontname,%                    %035
noresetatpart,etc,allowhyphens,captionfont,originalmathcomma,%       %040
frenchpack,halfnegthinspace,%     42
                    %
                    %   42 commandes definies apres \begin{document}%
                    %+ 154 commandes definies avant \begin{document}%
                    %= 196 commandes utilisables dans FrenchPro     %
%                   %-----------------------------------------------%
%%%%%%%%%%%%
%
% Macros not entered in the list or removed
%
%GOfrench,% is not a user command
%fguillemets,endfguillemets,%150 % removed 2000/03/08
%languagename is defined by babel
%slidename and listslidename will be in seminar too
%notesname is already in endnotes
%proofname is in AmS
%No, % was it really defined in the past?
%addto is defined by babel
]}%
\endinput
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
