% Classe `cours'.
% Copyright (c) Christian Obrecht 2005.

\ProvidesClass{fiche}

\LoadClass[a4paper]{article}
\RequirePackage{mafr}

\newcommand{\chapitre}[2]{\centerline{\bf\LARGE Chapitre #1 : #2}\bigskip}
